QuotaDetails class

Constructors

QuotaDetails({required num fromDatabase, required num fromExternal, required String nextRenewalDate})
QuotaDetails.fromJson(Map<String, dynamic> json)

Properties

fromDatabase num
latefinal
fromExternal num
latefinal
hashCode int
The hash code for this object.
no setterinherited
nextRenewalDate String
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited