RegimeTributario class

Constructors

RegimeTributario({required bool optante, String? dataOpcao, String? dataExclusao, String? ultimaAtualizacao})
RegimeTributario.fromJson(Map<String, dynamic> json)

Properties

dataExclusao String?
latefinal
dataOpcao String?
latefinal
hashCode int
The hash code for this object.
no setterinherited
optante bool
latefinal
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ultimaAtualizacao String?
latefinal

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited