SimplesDetalhe class
Constructors
- SimplesDetalhe({required bool optante, String? dataOpcao, SimplesHistorico? historico})
-
SimplesDetalhe.fromJson(Map<
String, dynamic> json)
Properties
- dataOpcao ↔ String?
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- historico ↔ SimplesHistorico?
-
latefinal
- optante ↔ bool
-
latefinal
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited