SimplesInfo class
Constructors
- SimplesInfo({required String cnpj, SimplesDetalhe? simples, SimplesDetalhe? simei, required Billing billing})
-
SimplesInfo.fromJson(Map<
String, dynamic> json)
Properties
- billing ↔ Billing
-
latefinal
- cnpj ↔ String
-
latefinal
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- simei ↔ SimplesDetalhe?
-
latefinal
- simples ↔ SimplesDetalhe?
-
latefinal
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited